clear all
close all

% Step test for Model 1 - CSTR
% Created by John Hedengren

global u

% Steady State Initial Conditions for the States
Ca_ss = 0.87725294608097;
T_ss = 324.475443431599;
x0 = [Ca_ss;T_ss];

% Steady State Initial Condition
u_ss = 300;
u = u_ss;

% Time Interval (min)
tf = 1/60;

cool(1) = u_ss;
Ca(1) = Ca_ss;
T(1) = T_ss;
time(1) = 0;
alpha = 0.1;

for i = 2:2401,
  % Open Loop Step Change
  if (i==2),
     u = 290;
  end
  
  if (i>=601),
      u = 300;
  end

  if (i>=1201),
     u = (280 + 20*sin(i/20))*alpha + (1-alpha)*u;
  end

  if (i>=1601),
      u = 300;
  end
  
  [t,x] = ode15s('cstr1',[0 tf],x0);

  % Parse out the state values
  time(i) = time(i-1) + tf;
  cool(i) = u;
  Ca(i) = x(end,1);
  T(i) = x(end,2);

  % add state noise
  Ca(i) = Ca(i) + (rand(1)-0.5)*0.005;
  T(i) = T(i) + (rand(1)-0.5)*0.05;
  
  % update x0
  x0(1) = Ca(i);
  x0(2) = T(i);
  
  % add measurement noise
  Ca(i) = Ca(i) + (rand(1)-0.5)*0.02;
  T(i) = T(i) + (rand(1)-0.5)*0.2;
end

% Plot the results
figure(1);
subplot(2,1,1)
plot(time,T,'b-','LineWidth',2);
hold on;
plot(time,cool,'k-.','LineWidth',2);
ylabel('T (K)')
legend('Reactor Temperature','Jacket Temperature')
axis([0 40 285 330])

subplot(2,1,2)
plot(time,Ca);
ylabel('C_a (mol/m^3)','LineWidth',2)
legend('Reactor Concentration')

M = [60*time' cool' Ca' T'];

save -ascii results.txt M